@@ -2,8 +2,8 @@ import torch
 import torch.optim as optim
 from torch.utils.data import DataLoader, sampler
 from tqdm import tqdm
-from data_reader import Word2vecDataset
-from model import SkipGramModel
+from word2vec.data_reader import Word2vecDataset
+from word2vec.model import SkipGramModel
 
 
 class Word2VecTrainer:
@@ -23,7 +23,6 @@ class Word2VecTrainer:
         self.iterations = iterations
         self.initial_lr = initial_lr
         self.skip_gram_model = SkipGramModel(self.emb_size, self.emb_dimension)
-        # print('parameters:',self.skip_gram_model.parameters())
 
         self.use_cuda = torch.cuda.is_available()
         self.device = torch.device("cuda" if self.use_cuda else "cpu")
